#!/bin/sh
#------------------------------------------------------------------------------
# /var/install/config.d/postgresql-update.sh - parameter update script
#
# Copyright (c) 2007 Daniel Vogel <daniel_vogel(at)t-online(dot)de>
#
# Creation:     2005-09-11 dv
# Last Update:  $Id: postgresql-update.sh 19650 2009-05-11 19:51:19Z dv $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#------------------------------------------------------------------------------
packages_name=postgresql

. /var/install/include/eislib
. /var/install/include/configlib

START_POSTGRESQL='yes'                     # Shall postgresql deamon be started

POSTGRESQL_NETWORKING='yes'                # Enable network access to PostgreSQL
POSTGRESQL_SERVER_PORT='5432'              # TCP/IP port for network access
POSTGRESQL_MAX_CONNECTS='50'               # max concurrent connects

POSTGRESQL_HOST_N='2'                      # number of host entries

POSTGRESQL_HOST_1_TYPE='local'             # Local or network(host) access?
POSTGRESQL_HOST_1_NETWORK=''               # IP-Address of host (or network) 1
POSTGRESQL_HOST_1_USERAUTH='trust'         # Authentication
POSTGRESQL_HOST_1_DATABASE='all'           # affected databases
POSTGRESQL_HOST_1_USER='all'               # affected users

POSTGRESQL_HOST_2_TYPE='host'              # Local or network(host) access?
POSTGRESQL_HOST_2_NETWORK='127.0.0.1/32'   # IP-Address of host (or network) 1
POSTGRESQL_HOST_2_USERAUTH='trust'         # Authentication
POSTGRESQL_HOST_2_DATABASE='all'           # affected databases
POSTGRESQL_HOST_2_USER='all'               # affected users

POSTGRESQL_BACKUP_SCHEDULE='30 0 * * *'    # cron schedule for autom. backup
POSTGRESQL_BACKUP_TARGET='/var/lib/pgsql_backup'
                                           # target directory for backups
POSTGRESQL_BACKUP_N='0'                    # Number of databases to backup
POSTGRESQL_BACKUP_1_DBNAME='template1'     # Name of database to backup
POSTGRESQL_BACKUP_1_USER='postgres'        # User to connect to db server
POSTGRESQL_BACKUP_1_MAX='7'                # Number of backup files to maintain
POSTGRESQL_BACKUP_MOUNT=''                 # Command executed before backup
POSTGRESQL_BACKUP_UMOUNT=''                # Command executed after backup
POSTGRESQL_BACKUP_NOTIFY='root@localhost'  # E-mail address for error notification

POSTGRESQL_AUTOVACUUM='yes'                # Start autovacuum process

# advanced options (resource truning)

POSTGRESQL_RESOURCE_TUNING='no'
POSTGRESQL_SHARED_MEM='16MB'               # size of shared memory block
POSTGRESQL_WORK_MEM='1MB'                  # size of per session memory
POSTGRESQL_TEMP_MEM='8MB'                  # size for temporary tables
POSTGRESQL_MAINTAIN_MEM='8MB'              # size for maintainance tasks
POSTGRESQL_PREP_TRANSACTIONS='5'           # max. number of prepared transactions

# advanced options (wal tuning)

POSTGRESQL_WAL_TUNING='no'
POSTGRESQL_FSYNC='yes'                     # switch fsync on or off
POSTGRESQL_SYNC_METHOD='fsync'             # fsync, fdatasync, open_sync, open_datasync
#POSTGRESQL_WAL_BUFFERS='8'                 # WAL buffers in memory, 8KB each
POSTGRESQL_WAL_DATA_MEM='64kB'             # the amount of memory used for WAL data
POSTGRESQL_COMMIT_DELAY='0'                # delay for writes on commits
POSTGRESQL_COMMIT_SIBLINGS='5'             # number of concurrent commits to delay
POSTGRESQL_CHECKPOINT_SECTIONS='3'         # number of sections before checkpoint
POSTGRESQL_CHECKPOINT_TIMEOUT='300'        # 300 sec. timeout
POSTGRESQL_CHECKPOINT_WARNING='30'         # default = 30, 0 = off

# advanced options (log options)

POSTGRESQL_LOG_SETTINGS='no'
POSTGRESQL_CLIENT_LOG_LEVEL='notice'      # log level for client programs
POSTGRESQL_SERVER_LOG_LEVEL='notice'      # log level for server log
POSTGRESQL_LOG_VERBOSE='no'               # verbose log messages
POSTGRESQL_LOG_STATEMENTS='no'            # writes SQL statements to log


#------------------------------------------------------------------------------
# rename old variables
#------------------------------------------------------------------------------
rename_old_variables()
{
    # read old values
    if [ -f /etc/config.d/${packages_name} ]
    then
        . /etc/config.d/${packages_name}

        if [ "${POSTGRESQL_RESOURCE_TUNING}" == 'yes' ]
        then
            if [ "${POSTGRESQL_SHARED_BUFFERS}" != "" ]
            then
                POSTGRESQL_SHARED_MEM="$[${POSTGRESQL_SHARED_BUFFERS} * 8]kB"
            fi

            if [ "${POSTGRESQL_TEMP_BUFFERS}" != "" ]
            then
                POSTGRESQL_TEMP_MEM="$[${POSTGRESQL_TEMP_BUFFERS} * 8]kB"
            fi
        fi

        if [ "${POSTGRESQL_WAL_TUNING}" == 'yes' ]
        then
            if [ "${POSTGRESQL_WAL_BUFFERS}" != "" ]
            then
                POSTGRESQL_WAL_DATA_MEM="$[${POSTGRESQL_WAL_BUFFERS} * 8]kB"
            fi
        fi
    fi
}


#------------------------------------------------------------------------------
# add new variables
#------------------------------------------------------------------------------
add_new_variables()
{
    # no variables added at this time
    echo "" > /dev/null
}


#------------------------------------------------------------------------------
# Write config and default files
#------------------------------------------------------------------------------
make_config_file()
{
    internal_conf_file=$1
    (
    printgpl -conf "$packages_name" "2006-12-16" "dv" \
         "2006 Daniel Vogel, daniel_vogel(at)t-online(dot)de"

    printgroup "PostgreSQL server settings"
    printvar "START_POSTGRESQL" "Shall PostgreSQL be started"

    printgroup "PostgreSQL network (TCP/IP) access"
    printvar "POSTGRESQL_NETWORKING" "Enable network access to PostgreSQL"
    printvar "POSTGRESQL_SERVER_PORT" "TCP/IP port for network access"
    printvar "POSTGRESQL_MAX_CONNECTS" "Max concurrent connects"

    printgroup "Host access table"
    printvar "POSTGRESQL_HOST_N" "Number of host entries"
    echo ""
    printvar "POSTGRESQL_HOST_1_TYPE" "Local or network access?"
    printvar "POSTGRESQL_HOST_1_NETWORK" "IP-Address of host or network"
    printvar "POSTGRESQL_HOST_1_USERAUTH" "Authentication"
    printvar "POSTGRESQL_HOST_1_DATABASE" "Affected databases or 'all' for all"
    printvar "POSTGRESQL_HOST_1_USER" "Affected users or 'all' for all"
    echo ""
    printvar "POSTGRESQL_HOST_2_TYPE" "Local or network access?"
    printvar "POSTGRESQL_HOST_2_NETWORK" "IP-Address of host or network"
    printvar "POSTGRESQL_HOST_2_USERAUTH" "Authentication"
    printvar "POSTGRESQL_HOST_2_DATABASE" "Affected databases or 'all' for all"
    printvar "POSTGRESQL_HOST_2_USER" "Affected users or 'all' for all"

    idx=3
    while [ "$idx" -le "$POSTGRESQL_HOST_N" ]
    do
       echo ""
       printvar "POSTGRESQL_HOST_${idx}_TYPE" "Local or network access?"
       printvar "POSTGRESQL_HOST_${idx}_NETWORK" "IP-Address of host or network"
       printvar "POSTGRESQL_HOST_${idx}_USERAUTH" "Authentication"
       printvar "POSTGRESQL_HOST_${idx}_DATABASE" "Affected databases or 'all' for all"
       printvar "POSTGRESQL_HOST_${idx}_USER" "Affected users or 'all' for all"
       idx=`/usr/bin/expr $idx + 1`
    done

    printgroup "Database backup"
    printvar "POSTGRESQL_BACKUP_SCHEDULE" "Cron schedule for autom. backup"
    printvar "POSTGRESQL_BACKUP_TARGET" "Target directory for backups"
    echo ""
    printvar "POSTGRESQL_BACKUP_N" "Number of databases to backup"
    printvar "POSTGRESQL_BACKUP_1_DBNAME" "Name of database to backup"
    printvar "POSTGRESQL_BACKUP_1_USER" "User to connect to db server"
    printvar "POSTGRESQL_BACKUP_1_MAX" "Number of backup files to maintain"
    idx=2
    while [ "$idx" -le "$POSTGRESQL_BACKUP_N" ]
    do
       echo ""
       printvar "POSTGRESQL_BACKUP_${idx}_DBNAME" "Name of database to backup"
       printvar "POSTGRESQL_BACKUP_${idx}_USER" "User to connect to db server"
       printvar "POSTGRESQL_BACKUP_${idx}_MAX" "Number of backup files to maintain"
       idx=`/usr/bin/expr $idx + 1`
    done
    echo ""
    printvar "POSTGRESQL_BACKUP_MOUNT" "Command executed before backup"
    printvar "POSTGRESQL_BACKUP_UMOUNT" "Command executed after backup"
    printvar "POSTGRESQL_BACKUP_NOTIFY" "E-mail address for error notification"

    printgroup "Automatic database optimization"
    printvar "POSTGRESQL_AUTOVACUUM" "Start autovacuum process"

    printgroup "Resource consumtion options (advanced)"
    printvar "POSTGRESQL_RESOURCE_TUNING" "Manually overwrite default settings?"
    printvar "POSTGRESQL_SHARED_MEM" "Size of shared memory block"
    printvar "POSTGRESQL_TEMP_MEM" "Size of temporary memory"
    printvar "POSTGRESQL_WORK_MEM" "Size of per session memory"
    printvar "POSTGRESQL_MAINTAIN_MEM" "Size for maintainance tasks"
    printvar "POSTGRESQL_PREP_TRANSACTIONS" "Max. number of prepared transact."

    printgroup "Write ahead log (WAL) options (advanced)"
    printvar "POSTGRESQL_WAL_TUNING" "Manually overwrite default settings?"
    printvar "POSTGRESQL_FSYNC" "Switch fsync on or off"
    printvar "POSTGRESQL_SYNC_METHOD" "fsync, fdatasync, open_sync, open_datasync"
    printvar "POSTGRESQL_WAL_DATA_MEM" "the amount of memory used for WAL data"
    printvar "POSTGRESQL_COMMIT_DELAY" "Delay for writes on commits"
    printvar "POSTGRESQL_COMMIT_SIBLINGS" "Number of concurrent commits to delay"
    printvar "POSTGRESQL_CHECKPOINT_SECTIONS" "Number of sections before checkpoint"
    printvar "POSTGRESQL_CHECKPOINT_TIMEOUT" "Timeout before checkpoint"
    printvar "POSTGRESQL_CHECKPOINT_WARNING" "Min. time between checkpoints"

    printgroup "Log options (advanced)"
    printvar "POSTGRESQL_LOG_SETTINGS" "manually overwrite default settings?"
    printvar "POSTGRESQL_CLIENT_LOG_LEVEL" "Log level for client programs"
    printvar "POSTGRESQL_SERVER_LOG_LEVEL" "log level for server log"
    printvar "POSTGRESQL_LOG_VERBOSE" "Verbose log messages"
    printvar "POSTGRESQL_LOG_STATEMENTS" "write SQL statements to log"

    printend
    ) > $internal_conf_file
    # Set rights
    chmod 0644 $internal_conf_file
    chown root $internal_conf_file
}

#----------------------------------------------------------------------------
# Create the check.d file
#----------------------------------------------------------------------------
make_check_file()
{
    (
    printgpl -check "$packages_name" "2007-03-03" "dv" \
         "2006 Daniel Vogel, daniel_vogel(at)t-online(dot)de"
    echo "START_POSTGRESQL                -                     -                   YESNO"
    echo "POSTGRESQL_NETWORKING           -                     -                   YESNO"
    echo "POSTGRESQL_SERVER_PORT          POSTGRESQL_NETWORKING -                   PORT"
    echo "POSTGRESQL_MAX_CONNECTS         -                     -                   NUMERIC"
    echo "POSTGRESQL_MAX_CONNECTS         -                     -                   PG_MAXCONN"
    echo "POSTGRESQL_HOST_N               -                     -                   NUMERIC"
    echo "POSTGRESQL_HOST_%_TYPE          -                     POSTGRESQL_HOST_N   PG_ACCESSTYPE"
    echo "POSTGRESQL_HOST_%_NETWORK       -                     POSTGRESQL_HOST_N   PG_NETWORK"
    echo "POSTGRESQL_HOST_%_USERAUTH      -                     POSTGRESQL_HOST_N   PG_AUTHENTICATION"
    echo "POSTGRESQL_HOST_%_DATABASE      -                     POSTGRESQL_HOST_N   NOTEMPTY"
    echo "POSTGRESQL_HOST_%_USER          -                     POSTGRESQL_HOST_N   NOTEMPTY"
    echo "POSTGRESQL_BACKUP_SCHEDULE      -                     -                   CRONTAB"
    echo "POSTGRESQL_BACKUP_TARGET        -                     -                   ABS_PATH"
    echo "POSTGRESQL_BACKUP_N             -                     -                   NUMERIC"
    echo "POSTGRESQL_BACKUP_%_DBNAME      -                     POSTGRESQL_BACKUP_N NOTEMPTY"
    echo "POSTGRESQL_BACKUP_%_USER        -                     POSTGRESQL_BACKUP_N NOTEMPTY"
    echo "POSTGRESQL_BACKUP_%_MAX         -                     POSTGRESQL_BACKUP_N NUMERIC"
    echo "POSTGRESQL_BACKUP_MOUNT         -                     -                   NONE"
    echo "POSTGRESQL_BACKUP_UMOUNT        -                     -                   NONE"
    echo "POSTGRESQL_BACKUP_NOTIFY        -                     -                   EMAILADDR"
    echo "POSTGRESQL_AUTOVACUUM           -                     -                   YESNO"

    echo "POSTGRESQL_RESOURCE_TUNING      -                           -             YESNO"
    echo "POSTGRESQL_SHARED_MEM           POSTGRESQL_RESOURCE_TUNING  -             PG_BYTENUM"
    echo "POSTGRESQL_TEMP_MEM             POSTGRESQL_RESOURCE_TUNING  -             PG_BYTENUM"
    echo "POSTGRESQL_WORK_MEM             POSTGRESQL_RESOURCE_TUNING  -             PG_BYTENUM"
    echo "POSTGRESQL_MAINTAIN_MEM         POSTGRESQL_RESOURCE_TUNING  -             PG_BYTENUM"
    echo "POSTGRESQL_PREP_TRANSACTIONS    POSTGRESQL_RESOURCE_TUNING  -             NUMERIC"

    echo "POSTGRESQL_WAL_TUNING           -                           -             YESNO"
    echo "POSTGRESQL_FSYNC                POSTGRESQL_WAL_TUNING       -             YESNO"
    echo "POSTGRESQL_SYNC_METHOD          POSTGRESQL_WAL_TUNING       -             PG_SYNCMETHOD"
    echo "POSTGRESQL_WAL_DATA_MEM         POSTGRESQL_WAL_TUNING       -             PG_BYTENUM"
    echo "POSTGRESQL_COMMIT_DELAY         POSTGRESQL_WAL_TUNING       -             NUMERIC"
    echo "POSTGRESQL_COMMIT_SIBLINGS      POSTGRESQL_WAL_TUNING       -             NUMERIC"
    echo "POSTGRESQL_CHECKPOINT_SECTIONS  POSTGRESQL_WAL_TUNING       -             NUMERIC"
    echo "POSTGRESQL_CHECKPOINT_TIMEOUT   POSTGRESQL_WAL_TUNING       -             NUMERIC"
    echo "POSTGRESQL_CHECKPOINT_WARNING   POSTGRESQL_WAL_TUNING       -             NUMERIC"

    echo "POSTGRESQL_LOG_SETTINGS         -                           -             YESNO"
    echo "POSTGRESQL_CLIENT_LOG_LEVEL     POSTGRESQL_LOG_SETTINGS     -             PG_LOGLEVEL"
    echo "POSTGRESQL_SERVER_LOG_LEVEL     POSTGRESQL_LOG_SETTINGS     -             PG_LOGLEVEL"
    echo "POSTGRESQL_LOG_VERBOSE          POSTGRESQL_LOG_SETTINGS     -             YESNO"
    echo "POSTGRESQL_LOG_STATEMENTS       POSTGRESQL_LOG_SETTINGS     -             YESNO"

    echo ""
    ) > /etc/check.d/$packages_name
    # Set rights for check.d file
    chmod 0644 /etc/check.d/$packages_name
    chown root /etc/check.d/$packages_name

    (
    printgpl -check_exp "$packages_name" "2009-04-26" "dv" \
         "2009 Daniel Vogel, daniel_vogel(at)t-online(dot)de"
    echo "PG_ACCESSTYPE         = 'local|host'"
    echo "                      : 'Wrong access type! Only \"local\" or \"host\" are"
    echo "                         allowed'"
    echo "PG_NETWORK            = '()|(RE:NETWORK)'"
    echo "                      : 'no valid network specification, should be a network"
    echo "                         address followed by a netmask, for instance 192.168.6.0/24'"
    echo "PG_AUTHENTICATION     = 'trust|reject|md5|crypt|password|krb4|krb5|ident|pam'"
    echo "                      : 'Wrong authentication method! Only \"trust\", \"reject\","
    echo "                         \"md5\", \"crypt\", \"password\", \"krb4\", \"krb5\","
    echo "                         \"ident\" or \"pam\" are allowed.'"
    echo "PG_SYNCMETHOD         = 'fsync|fdatasync'"
    echo "                      : 'Wrong sync method! Only \"fsync\", \"fdatasync\".'"
    echo "PG_LOGLEVEL           = 'debug5|debug4|debug3|debug2|debug1|log|notice|warning|error|fatal|panic'"
    echo "                      : 'Wrong loglevel! Only \"debug5\", \"debug4\", \"debug3\","
    echo "                         \"debug2\",\"debug1\", \"log\", \"notice\", \"warning\","
    echo "                         \"error\", \"fatal\", \"panic\" are allowed.'"
    echo "PG_BYTENUM            = '(RE:NUMERIC)(GB|MB|kB|())'"
    echo "                      : 'Wrong memory size given! Use number with optional postfix "
    echo "                         \"GB\", \"MB\" or \"kB\".'"
    echo "PG_MAXCONN            = '[1-9][0-9]{0,2}|[1][0-9]{3}|2000'"
    echo "                      : 'value must be in range 1..2000'"
    echo ""
    ) > /etc/check.d/${packages_name}.exp
    # Set rights for check.exp file
    chmod 0644 /etc/check.d/${packages_name}.exp
    chown root /etc/check.d/${packages_name}.exp

    (
    printgpl -check_ext "$packages_name" "2009-04-26" "dv" \
         "2009 Daniel Vogel, daniel_vogel(at)t-online(dot)de"
    echo "if (POSTGRESQL_RESOURCE_TUNING)"
    echo "then"
    echo "    # first we have to calculate real memory sizes from configuration"
    echo "    # values. This is done in a for index = 1 to 4 loop..."
    echo ""
    echo "    # prepare loop"
    echo "    set enumstr = \"1 2 3 4\""
    echo "    split (enumstr, enum_%, ' ')"
    echo ""
    echo "    # run loop"
    echo "    foreach index in enum_%"
    echo "    do"
    echo "        # initialize loop parameter"
    echo "        if (index == 1)"
    echo "        then"
    echo "            set memsizestr = POSTGRESQL_SHARED_MEM"
    echo "            set multiplyer = 8"
    echo "        fi"
    echo "        if (index == 2)"
    echo "        then"
    echo "            set memsizestr = POSTGRESQL_TEMP_MEM"
    echo "            set multiplyer = 8"
    echo "        fi"
    echo "        if (index == 3)"
    echo "        then"
    echo "            set memsizestr = POSTGRESQL_WORK_MEM"
    echo "            set multiplyer = 1"
    echo "        fi"
    echo "        if (index == 4)"
    echo "        then"
    echo "            set memsizestr = POSTGRESQL_MAINTAIN_MEM"
    echo "            set multiplyer = 1"
    echo "        fi"
    echo ""
    echo "        set memsize = 0"
    echo ""
    echo "        # split string and calculate result"
    echo "        split (memsizestr, test_%, 'G')"
    echo "        if (test_%[1] == memsizestr)"
    echo "        then"
    echo ""
    echo "            split (memsizestr, test_%, 'M')"
    echo "            if (test_%[1] == memsizestr)"
    echo "            then"
    echo ""
    echo "                split (memsizestr, test_%, 'k')"
    echo "                if (test_%[1] == memsizestr)"
    echo "                then"
    echo "                    split (memsizestr, test2_%, ' ', numeric)"
    echo "                    set memsize = (test2_%[1] * multiplyer)"
    echo "                else"
    echo "                    split (memsizestr, test2_%, 'k', numeric)"
    echo "                    set memsize = test2_%[1]"
    echo "                fi"
    echo ""
    echo "            else"
    echo "                split (memsizestr, test2_%, 'M', numeric)"
    echo "                set memsize = (test2_%[1] * 1024)"
    echo "            fi"
    echo ""
    echo "        else"
    echo "            split (memsizestr, test2_%, 'G', numeric)"
    echo "            set memsize = (test2_%[1] * 1024 * 1024)"
    echo "        fi"
    echo ""
    echo "        # assign result"
    echo "        if (index == 1)"
    echo "        then"
    echo "            set shared_mem = memsize"
    echo "        fi"
    echo "        if (index == 2)"
    echo "        then"
    echo "            set temp_mem = memsize"
    echo "        fi"
    echo "        if (index == 3)"
    echo "        then"
    echo "            set work_mem = memsize"
    echo "        fi"
    echo "        if (index == 4)"
    echo "        then"
    echo "            set maintain_mem = memsize"
    echo "        fi"
    echo "    done"
    echo ""
    echo "    # now we can check if memory sizes are out of bounds:"
    echo ""
    echo "    # check shared buffers to be larger then 128 kByte and larger then"
    echo "    # max_connections * 16"
    echo "    if ((shared_mem < 128) || (shared_mem < POSTGRESQL_MAX_CONNECTS * 16))"
    echo "    then"
    echo "        set required = POSTGRESQL_MAX_CONNECTS * 16"
    echo "        if (required < 128)"
    echo "        then"
    echo "            set required = 128"
    echo "        fi"
    echo "        error \"POSTGRESQL_SHARED_MEM to small! Abs. minimum is \${required}kB\""
    echo "    fi"
    echo "    if (shared_mem > 8589934584)"
    echo "    then"
    echo "        error \"POSTGRESQL_SHARED_MEM is outside of max. valid range (8192GB)\""
    echo "    fi"
    echo ""
    echo "    # check if temp_mem is in valid range (not sure about the upper limit)"
    echo "    if ((temp_mem < 800) || (temp_mem > 8589934584))"
    echo "    then"
    echo "        error \"POSTGRESQL_TEMP_MEM is outside of max. valid range (800KB .. 8192GB)\""
    echo "    fi"
    echo ""
    echo "    # check if work_mem is in valid range (not sure about the upper limit)"
    echo "    if ((work_mem < 64) || (work_mem > 2097151))"
    echo "    then"
    echo "        error \"POSTGRESQL_WORK_MEM is outside of valid range (64KB .. 2GB)\""
    echo "    fi"
    echo ""
    echo "    # check if maintain_mem is in valid range (not sure about the upper limit)"
    echo "    if ((maintain_mem < 1024) || (maintain_mem > 2097151))"
    echo "    then"
    echo "        error \"POSTGRESQL_MAINTAIN_MEM is outside of valid range (1MB .. 2GB)\""
    echo "    fi"
    echo ""
    echo "    # check if shared_buffers has a reasonable value (the limit is only an estimated"
    echo "    # one - only used to prevent the user from stating senseless values)"
    echo "    if (shared_mem > (1024 * 1024))"
    echo "    then"
    echo "        warning \"POSTGRESQL_SHARED_MEM seems very large. Please note that up to 10% of the physical memory is a reasonalble value.\""
    echo "    fi"
    echo ""
    echo "    # check if work_mem has a reasonable value (the limit is only an estimated"
    echo "    # one - only used to prevent the user from stating senseless values)"
    echo "    if (work_mem > (64 * 1024))"
    echo "    then"
    echo "        warning \"POSTGRESQL_WORK_MEM seems very large. For parallel sessions or complex queries this memory may be required many times.\""
    echo "    fi"
    echo "fi"
    echo ""
    echo "if (POSTGRESQL_WAL_TUNING)"
    echo "then"
    echo "    set memsizestr = POSTGRESQL_WAL_DATA_MEM"
    echo "    set multiplyer = 8"
    echo ""
    echo "    set memsize = 0"
    echo ""
    echo "    # split string and calculate result"
    echo "    split (memsizestr, test_%, 'G')"
    echo "    if (test_%[1] == memsizestr)"
    echo "    then"
    echo ""
    echo "        split (memsizestr, test_%, 'M')"
    echo "        if (test_%[1] == memsizestr)"
    echo "        then"
    echo ""
    echo "            split (memsizestr, test_%, 'k')"
    echo "            if (test_%[1] == memsizestr)"
    echo "            then"
    echo "                split (memsizestr, test2_%, ' ', numeric)"
    echo "                set memsize = (test2_%[1] * multiplyer)"
    echo "            else"
    echo "                split (memsizestr, test2_%, 'k', numeric)"
    echo "                set memsize = test2_%[1]"
    echo "            fi"
    echo ""
    echo "        else"
    echo "            split (memsizestr, test2_%, 'M', numeric)"
    echo "            set memsize = (test2_%[1] * 1024)"
    echo "        fi"
    echo ""
    echo "    else"
    echo "        split (memsizestr, test2_%, 'G', numeric)"
    echo "        set memsize = (test2_%[1] * 1024 * 1024)"
    echo "    fi"
    echo ""
    echo "    set wal_buffers = memsize"
    echo ""
    echo "    # check if wal_buffers is in valid range (not sure about the upper limit)"
    echo "    if ((wal_buffers < 32) || (wal_buffers > 17179869176))"
    echo "    then"
    echo "        error \"POSTGRESQL_WAL_DATA_MEM is outside of valid range (32kB .. 16GB)\""
    echo "    fi"
    echo "fi"
    echo ""
    ) > /etc/check.d/${packages_name}.ext
    # Set rights for check.exp file
    chmod 0644 /etc/check.d/${packages_name}.ext
    chown root /etc/check.d/${packages_name}.ext
}

#------------------------------------------------------------------------------
# Main
#------------------------------------------------------------------------------

mecho -info "Update of package configuration..."

# write default config file
make_config_file /etc/default.d/$packages_name

# update from old version
rename_old_variables
add_new_variables

# write new config file
make_config_file /etc/config.d/$packages_name

# write check.d file
make_check_file

#------------------------------------------------------------------------------
# End
#------------------------------------------------------------------------------
exit 0

